/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.csv;

/**
 * Process boolean columns in CSV file.
 * 
 * @author matthias
 */
public class BooleanColumn extends Column {

  private final int mask;
  private final String trueText;
  private final String falseText;
  
  /**
   * Constructor with bitmask, use default text for true and false
   * 
   * @param mask report only values with mask bit = 1
   */
  public BooleanColumn(int mask) {
    this.mask = mask;
    this.trueText = "true";
    this.falseText = "false";
  }
  
  /**
   * Constructor with bitmask, use supplied text for true and false
   * 
   * @param mask report only values with mask bit = 1
   * @param trueText text for true values
   * @param falseText text for false values
   */
  public BooleanColumn(int mask, String trueText, String falseText) {
    this.mask = mask;
    this.trueText = trueText;
    this.falseText = falseText;
  }
  
  @Override
  public String format(int value) {
    StringBuilder buf = new StringBuilder(32);
    int maskCheck = 1;
    boolean isNext = false;
    
    for (int i = 0; i < 8; i++, maskCheck <<= 1) {
      if ((mask & maskCheck) != 0) {
        if (isNext) {
          buf.append(", ");
        }
        
        buf.append(((value & maskCheck) != 0) ? trueText : falseText);
        isNext = true;
      }
    }
    
    return buf.toString();
  }
  
}
