/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.csv;

import java.text.DecimalFormat;
import java.text.DecimalFormatSymbols;

/**
 * Supports floating point columns. The value
 * will be scaled by the supplied factor.
 * 
 * @author matthias
 */
public class RealColumn extends Column{

  private final double factor;
  private final DecimalFormat formatter;
  
  /**
   * Constructor with scaling factor and formatting
   * template. Decimal seperator is always a . in CSV files.
   * 
   * @param factor
   * @param formatTemplate 
   */
  public RealColumn(double factor, String formatTemplate) {
    this.factor = factor;
    this.formatter = new DecimalFormat(formatTemplate);
    DecimalFormatSymbols dfs = new DecimalFormatSymbols();
    dfs.setDecimalSeparator('.');
    formatter.setDecimalFormatSymbols(dfs);
  }
  
  @Override
  public String format(int value) {
    return formatter.format(value * factor);
  }
}
