/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.sensors;

/**
 * Analog Input with AD1115
 * 
 * @author matthias
 */
public class AnalogIn extends SensorBase {
  
  private final int channel;
  private int options = 0;
  
  /**
   * Select Channel in Constructor
   * 
   * @param channel 
   */
  public AnalogIn(int channel) {
    this.channel = channel;
  }
  
  /**
   * Set configuration, e.g. Input Multiplexer,
   * conversion rate or gain. See ADS1115 data sheet.
   * 
   * @param startSingleShot
   * @param mux
   * @param gain
   * @param singleShot
   * @param rate
   * @param compMode
   * @param compPolarity
   * @param compLatch
   * @param compQueue 
   */
  public void setConfig(boolean startSingleShot, IMux mux, Gain gain, boolean singleShot, SampleRate rate, boolean compMode, boolean compPolarity, boolean compLatch, CompQueue compQueue) {
    int cmd = startSingleShot ? 0x8000 : 0x0;
    cmd |= ((mux.ordinal() & 0x7) << 12);
    cmd |= ((gain.ordinal() & 0x7) << 9);
    cmd |= singleShot ? 0x100 : 0;
    cmd |= ((rate.ordinal() & 0x7) << 5);
    cmd |= compMode ? 0x10 : 0;
    cmd |= compPolarity ? 0x8 : 0;
    cmd |= compLatch ? 0x4 : 0;
    cmd |= (compQueue.ordinal() & 0x3);
    
    options = cmd;
  }  
  
  /**
   * Get actual configuration
   * @return 
   */
  public int getConfig() {
    return options;
  }
  
  /**
   * Read analog value with retry on error.
   * @return 
   */
  public int getValue() {
    String path = "a/" + channel + "/" + options + "/0";
    int result = internalGetValue(path);
    
    return result;
  }
  
}

