/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.sensors;

/**
 * Writes byte values to MCP23017 Port Extender
 * 
 * @author matthias
 */
public class DigitalOut extends SensorBase {
  
  private final int channel;
  private int data;
  
  /**
   * Constructor with channel definition.
   * Each MCP supports two channels.
   * 
   * @param channel 
   */
  public DigitalOut(int channel) {
    this.channel = channel;
    data = 0;
  }
  
  /**
   * Writes a byte value to the selected channel.
   * 
   * @param value 
   */
  public void setValue(int value) {
    String path = "d/" + channel + "/0/" + value;
    data = value;
    internalGetValue(path);
  }
  
  /**
   * Set bit 0..7 to one.
   * @param bitNo 
   */
  public void setBit(int bitNo) {
    int value = data;
    value |= (1 << bitNo);
    setValue(value);
  }
  
  /**
   * Set bit 0..7 to zero
   * @param bitNo 
   */
  public void resetBit(int bitNo) {
    int value = data;
    value &= ~(1 << bitNo);
    setValue(value);
  }
  
  /**
   * Get local output value
   * @return 
   */
  public int getValue() {
    return data;
  }
}
