/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.sensors;

import java.io.IOException;
import java.net.URI;
import java.net.http.HttpClient;
import java.net.http.HttpRequest;
import java.net.http.HttpResponse;

/**
 *
 * @author matthias
 */
public abstract class SensorBase {
 
  /**
   * Retry counter for analog or digital read actions
   */
  public final static int MAX_RETRY = 10;

  /**
   * Send http request and return result body.
   * 
   * @param path
   * @return
   * @throws IOException
   * @throws InterruptedException 
   */
  protected String httpRequest(String path) throws IOException, InterruptedException {
    HttpClient client = HttpClient.newHttpClient();
    HttpRequest request = HttpRequest.newBuilder()
      .uri(URI.create("http://192.168.10.38/dataio/" + path))
      .build(); 
    
    HttpResponse<String> response = client.send(request, HttpResponse.BodyHandlers.ofString());  
    
    String[] parts = response.body().split("\\R");
    return parts[0];
  }

  protected int internalGetValue(String path) {
    for (int i = 0; i < MAX_RETRY; i++) {
      try {
        String result = httpRequest(path);
        return Integer.parseInt(result);
      } catch (IOException | InterruptedException ex) {
        //System.out.println(ex);
      }
    }
    
    return -1;
  }
  
  
}
