/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.csv;

import java.io.IOException;
import java.nio.file.Files;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 *
 * @author matthias
 */
public class CsvFileTest {
  
  /**
   * Test of formatRow method, of class CsvFile.
   */
  @Test
  public void testFormatRow() {
    System.out.println("formatRow");
    int[] values = {123, 2345, 6789, 15, 1};
    CsvFile instance = new CsvFile("test");
    instance.addColumn(new RationalColumn(1, 1));
    instance.addColumn(new RationalColumn(10, 9));
    instance.addColumn(new RealColumn(10.0 / 9.0, "#.###"));
    instance.addColumn(new BooleanColumn(0x1, "+", "-"));
    instance.addColumn(new BooleanColumn(0x3));
    String expResult = "123, 2605, 7543.333, +, true, false";
    
    String result = instance.formatRow(values);
    assertEquals(expResult, result);
    
    result = instance.formatRow(123, 2345, 6789, 15, 1);
    assertEquals(expResult, result);
  }
  
  /**
   * Test of addRow method, of class CsvFile.
   * @throws java.io.IOException
   */
  @Test
  public void testAddRow() throws IOException {
    System.out.println("addRow");
    int[] values = {123, 2345, 6789, 15, 1};
    CsvFile instance = new CsvFile("test");
    instance.addColumn(new RationalColumn(1, 1));
    instance.addColumn(new RationalColumn(10, 9));
    instance.addColumn(new RealColumn(10.0 / 9.0, "#.###"));
    instance.addColumn(new BooleanColumn(0x1, "+", "-"));
    instance.addColumn(new BooleanColumn(0x3));
    String expResult = "123, 2605, 7543.333, +, true, false";
    instance.addRow(values);
    instance.close();
    
    String result = Files.readString(instance.getPath());
    assertEquals(expResult, result);
  }
  
  /**
   * Test of addRow method, of class CsvFile.
   * @throws java.io.IOException
   */
  @Test
  public void testAddRows() throws IOException {
    System.out.println("addRows");
    int[] values = {123, 2345, 6789};
    CsvFile instance = new CsvFile("test");
    instance.addColumn(new RationalColumn(1, 1));
    instance.addColumn(new RationalColumn(10, 9));
    instance.addColumn(new RealColumn(10.0 / 9.0, "#.###"));
    String expResult = "123, 2605, 7543.333";
    instance.addRow(values);
    instance.addRow(values);
    instance.close();
    
    expResult = expResult + "\r\n" + expResult;
    String result = Files.readString(instance.getPath());
    assertEquals(expResult, result);
    

  }
}
