/*
 * DataIO Library for ESP32 I2C Sensor access
 *
 * (c) 2020 Matthias Thiele
 */
package de.mmth.dataio.sensors;

import static junit.framework.Assert.assertEquals;
import static junit.framework.Assert.assertTrue;
import org.junit.Test;



/**
 *
 * @author matthias
 */
public class AnalogInTest {
  
  /**
   * Test of setConfig method, of class AnalogIn.
   */
  @Test
  public void testSetConfig() {
    System.out.println("setConfig");
    boolean startSingleShot = false;
    IMux mux = IMux.AIN01;
    Gain gain = Gain.FSR6144;
    boolean singleShot = false;
    SampleRate rate = SampleRate.SPS8;
    boolean compMode = false;
    boolean compPolarity = false;
    boolean compLatch = false;
    CompQueue compQueue = CompQueue.ASSERT1;
    AnalogIn instance = new AnalogIn(0);
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    int result = instance.getConfig();
    assertEquals("Empty configuration.", 0, result);
    
    startSingleShot = true;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    startSingleShot = false;
    assertEquals("Single shot set.", 0x8000, result);  
    
    mux = IMux.AIN23;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    mux = IMux.AIN01;
    assertEquals("Mux set.", 0x3000, result);  
    
    gain = Gain.FSR0256;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    gain = Gain.FSR6144;
    assertEquals("Gain set.", 0xa00, result);  
    
    singleShot = true;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    singleShot = false;
    assertEquals("Single shot.", 0x100, result);
    
    rate = SampleRate.SPS16;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    rate = SampleRate.SPS8;
    assertEquals("Gain set.", 0x20, result);  
    
    compMode = true;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    compMode = false;
    assertEquals("Comp mode.", 0x10, result);
    
    compPolarity = true;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    compPolarity = false;
    assertEquals("Comp polarity.", 0x8, result);
    
    compLatch = true;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    compLatch = false;
    assertEquals("Comp latch.", 0x4, result);
    
    compQueue = CompQueue.ASSERTDISABLE;
    instance.setConfig(startSingleShot, mux, gain, singleShot, rate, compMode, compPolarity, compLatch, compQueue);
    result = instance.getConfig();
    assertEquals("Comp Queue.", 0x3, result);  
  }

  /**
   * Test of getValue method, of class AnalogIn.
   */
  @Test
  public void testGetValue() {
    System.out.println("getValue");
    AnalogIn instance = new AnalogIn(0);
    instance.setConfig(false, IMux.AIN0, Gain.FSR0256, false, SampleRate.SPS8, false, false, false, CompQueue.ASSERTDISABLE);
    int result = instance.getValue();
    assertTrue("Negative return indicates an error.", result >= 0);
  }
  
}
